
import os
from time import time
import cups
from flask import Flask, render_template, request, send_from_directory
from werkzeug.utils import secure_filename

app = Flask(__name__)
app.config['UPLOAD_FOLDER'] = "/tmp/web2print"
os.makedirs("/tmp/web2print", exist_ok=True)

@app.route('/assets/<string:resource>')
def assets(resource):
    return send_from_directory("assets", resource)

def get_printers():
    conn = cups.Connection()
    return list(conn.getPrinters())

@app.route('/', methods=["POST", "GET"])
def index():
    if (request.method == "GET") or ("document" not in request.files) or \
            (not request.files["document"].filename) or \
            ("printer" not in request.form) or (not request.form["printer"]):
        return render_template("index.html", printers=printers)


    printer = request.form["printer"]
    if printer not in printers:
        printer = printers[0]

    file = request.files['document']
    filename = secure_filename(file.filename)
    local_path = os.path.join(app.config['UPLOAD_FOLDER'], filename)
    file.save(local_path)

    conn = cups.Connection()
    conn.printFile(printer, local_path, "web2print-%d" % time(),
                   {"fit-to-page": "True", "sides": "two-sided-long-edge"})

    try:
        os.remove(local_path)
    except OSError:
        pass

    return "ok"

if __name__ == '__main__':
    printers = get_printers()
    app.run(host="0.0.0.0")
